import requests


def send_message(username, auth_token, to, message):

    if (username == '') or (auth_token == '') or (to == '') or (message == ''):
        response = 'Please Fill In All The Details'
        return response

    else:
        url = f'http://apis.bulksmszim.co.zw/texts.php?username={username}&salt={auth_token}&destinations={to}&message={message}'
        response = requests.post(url=url)
        return response.reason




import setuptools
from setuptools import setup

with open('README.md') as fh:
    long_description = fh.read()


setup(
    name='BulkSmsZim',
    version='1.2.1',
    author='Marlvin Chihota',
    author_email='info@marlvinzw.me',
    description='A Helper Library For Sending Text Messages For BulkSmsZimApi',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/MarlvinzW/BulkSmsZim-Api',
    download_url='https://github.com/MarlvinzW/BulkSmsZim-Api',
    install_requires=['requests'],
    py_modules=['BulkSmsZimApi'],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
